@@ -2,14 +2,22 @@
 
 from distutils.core import setup
 
+long_desc = ''
+prerelease_version = ''
+
 with open("README.md", "r", encoding="utf-8") as fh:
-    long_description = fh.read()
+    long_desc = fh.read()
+    fh.close()
+
+with open("version.txt", "r", encoding="utf-8") as fh:
+    prerelease_version = fh.read()
+    fh.close()
 
 setup(name='fresh-canvas-prerelease',
-      version='0.1.7',
+      version=prerelease_version,
       py_modules=['fresh-canvas'],
       description='Fresh Canvas [Pre-Release] | The Project Base',
-      long_description=long_description,
+      long_description=long_desc,
       long_description_content_type="text/markdown",
       author='Tushar Iyer',
       author_email='',
